"""
Type annotations for entityresolution service type definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_entityresolution.type_defs import AddPolicyStatementInputTypeDef

    data: AddPolicyStatementInputTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping, Sequence
from datetime import datetime
from typing import Any, Union

from .literals import (
    AttributeMatchingModelType,
    DeleteUniqueIdErrorTypeType,
    DeleteUniqueIdStatusType,
    IdMappingTypeType,
    IdMappingWorkflowRuleDefinitionTypeType,
    IdNamespaceTypeType,
    JobStatusType,
    JobTypeType,
    MatchPurposeType,
    ProcessingTypeType,
    RecordMatchingModelType,
    ResolutionTypeType,
    SchemaAttributeTypeType,
    ServiceTypeType,
    StatementEffectType,
)

if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict

__all__ = (
    "AddPolicyStatementInputTypeDef",
    "AddPolicyStatementOutputTypeDef",
    "BatchDeleteUniqueIdInputTypeDef",
    "BatchDeleteUniqueIdOutputTypeDef",
    "CreateIdMappingWorkflowInputTypeDef",
    "CreateIdMappingWorkflowOutputTypeDef",
    "CreateIdNamespaceInputTypeDef",
    "CreateIdNamespaceOutputTypeDef",
    "CreateMatchingWorkflowInputTypeDef",
    "CreateMatchingWorkflowOutputTypeDef",
    "CreateSchemaMappingInputTypeDef",
    "CreateSchemaMappingOutputTypeDef",
    "CustomerProfilesIntegrationConfigTypeDef",
    "DeleteIdMappingWorkflowInputTypeDef",
    "DeleteIdMappingWorkflowOutputTypeDef",
    "DeleteIdNamespaceInputTypeDef",
    "DeleteIdNamespaceOutputTypeDef",
    "DeleteMatchingWorkflowInputTypeDef",
    "DeleteMatchingWorkflowOutputTypeDef",
    "DeletePolicyStatementInputTypeDef",
    "DeletePolicyStatementOutputTypeDef",
    "DeleteSchemaMappingInputTypeDef",
    "DeleteSchemaMappingOutputTypeDef",
    "DeleteUniqueIdErrorTypeDef",
    "DeletedUniqueIdTypeDef",
    "ErrorDetailsTypeDef",
    "FailedRecordTypeDef",
    "GenerateMatchIdInputTypeDef",
    "GenerateMatchIdOutputTypeDef",
    "GetIdMappingJobInputTypeDef",
    "GetIdMappingJobOutputTypeDef",
    "GetIdMappingWorkflowInputTypeDef",
    "GetIdMappingWorkflowOutputTypeDef",
    "GetIdNamespaceInputTypeDef",
    "GetIdNamespaceOutputTypeDef",
    "GetMatchIdInputTypeDef",
    "GetMatchIdOutputTypeDef",
    "GetMatchingJobInputTypeDef",
    "GetMatchingJobOutputTypeDef",
    "GetMatchingWorkflowInputTypeDef",
    "GetMatchingWorkflowOutputTypeDef",
    "GetPolicyInputTypeDef",
    "GetPolicyOutputTypeDef",
    "GetProviderServiceInputTypeDef",
    "GetProviderServiceOutputTypeDef",
    "GetSchemaMappingInputTypeDef",
    "GetSchemaMappingOutputTypeDef",
    "IdMappingIncrementalRunConfigTypeDef",
    "IdMappingJobMetricsTypeDef",
    "IdMappingJobOutputSourceTypeDef",
    "IdMappingRuleBasedPropertiesOutputTypeDef",
    "IdMappingRuleBasedPropertiesTypeDef",
    "IdMappingTechniquesOutputTypeDef",
    "IdMappingTechniquesTypeDef",
    "IdMappingTechniquesUnionTypeDef",
    "IdMappingWorkflowInputSourceTypeDef",
    "IdMappingWorkflowOutputSourceTypeDef",
    "IdMappingWorkflowSummaryTypeDef",
    "IdNamespaceIdMappingWorkflowMetadataTypeDef",
    "IdNamespaceIdMappingWorkflowPropertiesOutputTypeDef",
    "IdNamespaceIdMappingWorkflowPropertiesTypeDef",
    "IdNamespaceIdMappingWorkflowPropertiesUnionTypeDef",
    "IdNamespaceInputSourceTypeDef",
    "IdNamespaceSummaryTypeDef",
    "IncrementalRunConfigTypeDef",
    "InputSourceTypeDef",
    "IntermediateSourceConfigurationTypeDef",
    "JobMetricsTypeDef",
    "JobOutputSourceTypeDef",
    "JobSummaryTypeDef",
    "ListIdMappingJobsInputPaginateTypeDef",
    "ListIdMappingJobsInputTypeDef",
    "ListIdMappingJobsOutputTypeDef",
    "ListIdMappingWorkflowsInputPaginateTypeDef",
    "ListIdMappingWorkflowsInputTypeDef",
    "ListIdMappingWorkflowsOutputTypeDef",
    "ListIdNamespacesInputPaginateTypeDef",
    "ListIdNamespacesInputTypeDef",
    "ListIdNamespacesOutputTypeDef",
    "ListMatchingJobsInputPaginateTypeDef",
    "ListMatchingJobsInputTypeDef",
    "ListMatchingJobsOutputTypeDef",
    "ListMatchingWorkflowsInputPaginateTypeDef",
    "ListMatchingWorkflowsInputTypeDef",
    "ListMatchingWorkflowsOutputTypeDef",
    "ListProviderServicesInputPaginateTypeDef",
    "ListProviderServicesInputTypeDef",
    "ListProviderServicesOutputTypeDef",
    "ListSchemaMappingsInputPaginateTypeDef",
    "ListSchemaMappingsInputTypeDef",
    "ListSchemaMappingsOutputTypeDef",
    "ListTagsForResourceInputTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "MatchGroupTypeDef",
    "MatchedRecordTypeDef",
    "MatchingWorkflowSummaryTypeDef",
    "NamespaceProviderPropertiesOutputTypeDef",
    "NamespaceProviderPropertiesTypeDef",
    "NamespaceProviderPropertiesUnionTypeDef",
    "NamespaceRuleBasedPropertiesOutputTypeDef",
    "NamespaceRuleBasedPropertiesTypeDef",
    "NamespaceRuleBasedPropertiesUnionTypeDef",
    "OutputAttributeTypeDef",
    "OutputSourceOutputTypeDef",
    "OutputSourceTypeDef",
    "OutputSourceUnionTypeDef",
    "PaginatorConfigTypeDef",
    "ProviderComponentSchemaTypeDef",
    "ProviderEndpointConfigurationTypeDef",
    "ProviderIdNameSpaceConfigurationTypeDef",
    "ProviderIntermediateDataAccessConfigurationTypeDef",
    "ProviderMarketplaceConfigurationTypeDef",
    "ProviderPropertiesOutputTypeDef",
    "ProviderPropertiesTypeDef",
    "ProviderSchemaAttributeTypeDef",
    "ProviderServiceSummaryTypeDef",
    "PutPolicyInputTypeDef",
    "PutPolicyOutputTypeDef",
    "RecordTypeDef",
    "ResolutionTechniquesOutputTypeDef",
    "ResolutionTechniquesTypeDef",
    "ResolutionTechniquesUnionTypeDef",
    "ResponseMetadataTypeDef",
    "RuleBasedPropertiesOutputTypeDef",
    "RuleBasedPropertiesTypeDef",
    "RuleConditionPropertiesOutputTypeDef",
    "RuleConditionPropertiesTypeDef",
    "RuleConditionTypeDef",
    "RuleOutputTypeDef",
    "RuleTypeDef",
    "RuleUnionTypeDef",
    "SchemaInputAttributeTypeDef",
    "SchemaMappingSummaryTypeDef",
    "StartIdMappingJobInputTypeDef",
    "StartIdMappingJobOutputTypeDef",
    "StartMatchingJobInputTypeDef",
    "StartMatchingJobOutputTypeDef",
    "TagResourceInputTypeDef",
    "UntagResourceInputTypeDef",
    "UpdateIdMappingWorkflowInputTypeDef",
    "UpdateIdMappingWorkflowOutputTypeDef",
    "UpdateIdNamespaceInputTypeDef",
    "UpdateIdNamespaceOutputTypeDef",
    "UpdateMatchingWorkflowInputTypeDef",
    "UpdateMatchingWorkflowOutputTypeDef",
    "UpdateSchemaMappingInputTypeDef",
    "UpdateSchemaMappingOutputTypeDef",
)

class AddPolicyStatementInputTypeDef(TypedDict):
    arn: str
    statementId: str
    effect: StatementEffectType
    action: Sequence[str]
    principal: Sequence[str]
    condition: NotRequired[str]

class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]

class BatchDeleteUniqueIdInputTypeDef(TypedDict):
    workflowName: str
    uniqueIds: Sequence[str]
    inputSource: NotRequired[str]

class DeleteUniqueIdErrorTypeDef(TypedDict):
    uniqueId: str
    errorType: DeleteUniqueIdErrorTypeType

class DeletedUniqueIdTypeDef(TypedDict):
    uniqueId: str

class IdMappingIncrementalRunConfigTypeDef(TypedDict):
    incrementalRunType: NotRequired[Literal["ON_DEMAND"]]

IdMappingWorkflowInputSourceTypeDef = TypedDict(
    "IdMappingWorkflowInputSourceTypeDef",
    {
        "inputSourceARN": str,
        "schemaName": NotRequired[str],
        "type": NotRequired[IdNamespaceTypeType],
    },
)

class IdMappingWorkflowOutputSourceTypeDef(TypedDict):
    outputS3Path: str
    KMSArn: NotRequired[str]

class IdNamespaceInputSourceTypeDef(TypedDict):
    inputSourceARN: str
    schemaName: NotRequired[str]

class IncrementalRunConfigTypeDef(TypedDict):
    incrementalRunType: NotRequired[Literal["IMMEDIATE"]]

class InputSourceTypeDef(TypedDict):
    inputSourceARN: str
    schemaName: str
    applyNormalization: NotRequired[bool]

SchemaInputAttributeTypeDef = TypedDict(
    "SchemaInputAttributeTypeDef",
    {
        "fieldName": str,
        "type": SchemaAttributeTypeType,
        "groupName": NotRequired[str],
        "matchKey": NotRequired[str],
        "subType": NotRequired[str],
        "hashed": NotRequired[bool],
    },
)

class CustomerProfilesIntegrationConfigTypeDef(TypedDict):
    domainArn: str
    objectTypeArn: str

class DeleteIdMappingWorkflowInputTypeDef(TypedDict):
    workflowName: str

class DeleteIdNamespaceInputTypeDef(TypedDict):
    idNamespaceName: str

class DeleteMatchingWorkflowInputTypeDef(TypedDict):
    workflowName: str

class DeletePolicyStatementInputTypeDef(TypedDict):
    arn: str
    statementId: str

class DeleteSchemaMappingInputTypeDef(TypedDict):
    schemaName: str

class ErrorDetailsTypeDef(TypedDict):
    errorMessage: NotRequired[str]

class FailedRecordTypeDef(TypedDict):
    inputSourceARN: str
    uniqueId: str
    errorMessage: str

class RecordTypeDef(TypedDict):
    inputSourceARN: str
    uniqueId: str
    recordAttributeMap: Mapping[str, str]

class GetIdMappingJobInputTypeDef(TypedDict):
    workflowName: str
    jobId: str

class IdMappingJobMetricsTypeDef(TypedDict):
    inputRecords: NotRequired[int]
    totalRecordsProcessed: NotRequired[int]
    recordsNotProcessed: NotRequired[int]
    deleteRecordsProcessed: NotRequired[int]
    totalMappedRecords: NotRequired[int]
    totalMappedSourceRecords: NotRequired[int]
    totalMappedTargetRecords: NotRequired[int]
    uniqueRecordsLoaded: NotRequired[int]
    newMappedRecords: NotRequired[int]
    newMappedSourceRecords: NotRequired[int]
    newMappedTargetRecords: NotRequired[int]
    newUniqueRecordsLoaded: NotRequired[int]
    mappedRecordsRemoved: NotRequired[int]
    mappedSourceRecordsRemoved: NotRequired[int]
    mappedTargetRecordsRemoved: NotRequired[int]

class IdMappingJobOutputSourceTypeDef(TypedDict):
    roleArn: str
    outputS3Path: str
    KMSArn: NotRequired[str]

class GetIdMappingWorkflowInputTypeDef(TypedDict):
    workflowName: str

class GetIdNamespaceInputTypeDef(TypedDict):
    idNamespaceName: str

class GetMatchIdInputTypeDef(TypedDict):
    workflowName: str
    record: Mapping[str, str]
    applyNormalization: NotRequired[bool]

class GetMatchingJobInputTypeDef(TypedDict):
    workflowName: str
    jobId: str

class JobMetricsTypeDef(TypedDict):
    inputRecords: NotRequired[int]
    totalRecordsProcessed: NotRequired[int]
    recordsNotProcessed: NotRequired[int]
    deleteRecordsProcessed: NotRequired[int]
    matchIDs: NotRequired[int]

class JobOutputSourceTypeDef(TypedDict):
    roleArn: str
    outputS3Path: str
    KMSArn: NotRequired[str]

class GetMatchingWorkflowInputTypeDef(TypedDict):
    workflowName: str

class GetPolicyInputTypeDef(TypedDict):
    arn: str

class GetProviderServiceInputTypeDef(TypedDict):
    providerName: str
    providerServiceName: str

class ProviderIdNameSpaceConfigurationTypeDef(TypedDict):
    description: NotRequired[str]
    providerTargetConfigurationDefinition: NotRequired[dict[str, Any]]
    providerSourceConfigurationDefinition: NotRequired[dict[str, Any]]

class ProviderIntermediateDataAccessConfigurationTypeDef(TypedDict):
    awsAccountIds: NotRequired[list[str]]
    requiredBucketActions: NotRequired[list[str]]

class GetSchemaMappingInputTypeDef(TypedDict):
    schemaName: str

class RuleOutputTypeDef(TypedDict):
    ruleName: str
    matchingKeys: list[str]

class RuleTypeDef(TypedDict):
    ruleName: str
    matchingKeys: Sequence[str]

class IdMappingWorkflowSummaryTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    createdAt: datetime
    updatedAt: datetime

class IdNamespaceIdMappingWorkflowMetadataTypeDef(TypedDict):
    idMappingType: IdMappingTypeType

class NamespaceProviderPropertiesOutputTypeDef(TypedDict):
    providerServiceArn: str
    providerConfiguration: NotRequired[dict[str, Any]]

class IntermediateSourceConfigurationTypeDef(TypedDict):
    intermediateS3Path: str

class JobSummaryTypeDef(TypedDict):
    jobId: str
    status: JobStatusType
    startTime: datetime
    endTime: NotRequired[datetime]

class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]

class ListIdMappingJobsInputTypeDef(TypedDict):
    workflowName: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListIdMappingWorkflowsInputTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListIdNamespacesInputTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListMatchingJobsInputTypeDef(TypedDict):
    workflowName: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListMatchingWorkflowsInputTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class MatchingWorkflowSummaryTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    createdAt: datetime
    updatedAt: datetime
    resolutionType: ResolutionTypeType

class ListProviderServicesInputTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]
    providerName: NotRequired[str]

class ProviderServiceSummaryTypeDef(TypedDict):
    providerServiceArn: str
    providerName: str
    providerServiceDisplayName: str
    providerServiceName: str
    providerServiceType: ServiceTypeType

class ListSchemaMappingsInputTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class SchemaMappingSummaryTypeDef(TypedDict):
    schemaName: str
    schemaArn: str
    createdAt: datetime
    updatedAt: datetime
    hasWorkflows: bool

class ListTagsForResourceInputTypeDef(TypedDict):
    resourceArn: str

class MatchedRecordTypeDef(TypedDict):
    inputSourceARN: str
    recordId: str

class NamespaceProviderPropertiesTypeDef(TypedDict):
    providerServiceArn: str
    providerConfiguration: NotRequired[Mapping[str, Any]]

class OutputAttributeTypeDef(TypedDict):
    name: str
    hashed: NotRequired[bool]

ProviderSchemaAttributeTypeDef = TypedDict(
    "ProviderSchemaAttributeTypeDef",
    {
        "fieldName": str,
        "type": SchemaAttributeTypeType,
        "subType": NotRequired[str],
        "hashing": NotRequired[bool],
    },
)

class ProviderMarketplaceConfigurationTypeDef(TypedDict):
    dataSetId: str
    revisionId: str
    assetId: str
    listingId: str

class PutPolicyInputTypeDef(TypedDict):
    arn: str
    policy: str
    token: NotRequired[str]

class RuleConditionTypeDef(TypedDict):
    ruleName: str
    condition: str

class StartMatchingJobInputTypeDef(TypedDict):
    workflowName: str

class TagResourceInputTypeDef(TypedDict):
    resourceArn: str
    tags: Mapping[str, str]

class UntagResourceInputTypeDef(TypedDict):
    resourceArn: str
    tagKeys: Sequence[str]

class AddPolicyStatementOutputTypeDef(TypedDict):
    arn: str
    token: str
    policy: str
    ResponseMetadata: ResponseMetadataTypeDef

class DeleteIdMappingWorkflowOutputTypeDef(TypedDict):
    message: str
    ResponseMetadata: ResponseMetadataTypeDef

class DeleteIdNamespaceOutputTypeDef(TypedDict):
    message: str
    ResponseMetadata: ResponseMetadataTypeDef

class DeleteMatchingWorkflowOutputTypeDef(TypedDict):
    message: str
    ResponseMetadata: ResponseMetadataTypeDef

class DeletePolicyStatementOutputTypeDef(TypedDict):
    arn: str
    token: str
    policy: str
    ResponseMetadata: ResponseMetadataTypeDef

class DeleteSchemaMappingOutputTypeDef(TypedDict):
    message: str
    ResponseMetadata: ResponseMetadataTypeDef

class GetMatchIdOutputTypeDef(TypedDict):
    matchId: str
    matchRule: str
    ResponseMetadata: ResponseMetadataTypeDef

class GetPolicyOutputTypeDef(TypedDict):
    arn: str
    token: str
    policy: str
    ResponseMetadata: ResponseMetadataTypeDef

class ListTagsForResourceOutputTypeDef(TypedDict):
    tags: dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef

class PutPolicyOutputTypeDef(TypedDict):
    arn: str
    token: str
    policy: str
    ResponseMetadata: ResponseMetadataTypeDef

class StartMatchingJobOutputTypeDef(TypedDict):
    jobId: str
    ResponseMetadata: ResponseMetadataTypeDef

class BatchDeleteUniqueIdOutputTypeDef(TypedDict):
    status: DeleteUniqueIdStatusType
    errors: list[DeleteUniqueIdErrorTypeDef]
    deleted: list[DeletedUniqueIdTypeDef]
    disconnectedUniqueIds: list[str]
    ResponseMetadata: ResponseMetadataTypeDef

class CreateSchemaMappingInputTypeDef(TypedDict):
    schemaName: str
    mappedInputFields: Sequence[SchemaInputAttributeTypeDef]
    description: NotRequired[str]
    tags: NotRequired[Mapping[str, str]]

class CreateSchemaMappingOutputTypeDef(TypedDict):
    schemaName: str
    schemaArn: str
    description: str
    mappedInputFields: list[SchemaInputAttributeTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

class GetSchemaMappingOutputTypeDef(TypedDict):
    schemaName: str
    schemaArn: str
    description: str
    mappedInputFields: list[SchemaInputAttributeTypeDef]
    createdAt: datetime
    updatedAt: datetime
    tags: dict[str, str]
    hasWorkflows: bool
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateSchemaMappingInputTypeDef(TypedDict):
    schemaName: str
    mappedInputFields: Sequence[SchemaInputAttributeTypeDef]
    description: NotRequired[str]

class UpdateSchemaMappingOutputTypeDef(TypedDict):
    schemaName: str
    schemaArn: str
    description: str
    mappedInputFields: list[SchemaInputAttributeTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

class GenerateMatchIdInputTypeDef(TypedDict):
    workflowName: str
    records: Sequence[RecordTypeDef]
    processingType: NotRequired[ProcessingTypeType]

class GetIdMappingJobOutputTypeDef(TypedDict):
    jobId: str
    status: JobStatusType
    startTime: datetime
    endTime: datetime
    metrics: IdMappingJobMetricsTypeDef
    errorDetails: ErrorDetailsTypeDef
    outputSourceConfig: list[IdMappingJobOutputSourceTypeDef]
    jobType: JobTypeType
    ResponseMetadata: ResponseMetadataTypeDef

class StartIdMappingJobInputTypeDef(TypedDict):
    workflowName: str
    outputSourceConfig: NotRequired[Sequence[IdMappingJobOutputSourceTypeDef]]
    jobType: NotRequired[JobTypeType]

class StartIdMappingJobOutputTypeDef(TypedDict):
    jobId: str
    outputSourceConfig: list[IdMappingJobOutputSourceTypeDef]
    jobType: JobTypeType
    ResponseMetadata: ResponseMetadataTypeDef

class GetMatchingJobOutputTypeDef(TypedDict):
    jobId: str
    status: JobStatusType
    startTime: datetime
    endTime: datetime
    metrics: JobMetricsTypeDef
    errorDetails: ErrorDetailsTypeDef
    outputSourceConfig: list[JobOutputSourceTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

class IdMappingRuleBasedPropertiesOutputTypeDef(TypedDict):
    ruleDefinitionType: IdMappingWorkflowRuleDefinitionTypeType
    attributeMatchingModel: AttributeMatchingModelType
    recordMatchingModel: RecordMatchingModelType
    rules: NotRequired[list[RuleOutputTypeDef]]

class NamespaceRuleBasedPropertiesOutputTypeDef(TypedDict):
    rules: NotRequired[list[RuleOutputTypeDef]]
    ruleDefinitionTypes: NotRequired[list[IdMappingWorkflowRuleDefinitionTypeType]]
    attributeMatchingModel: NotRequired[AttributeMatchingModelType]
    recordMatchingModels: NotRequired[list[RecordMatchingModelType]]

class RuleBasedPropertiesOutputTypeDef(TypedDict):
    rules: list[RuleOutputTypeDef]
    attributeMatchingModel: AttributeMatchingModelType
    matchPurpose: NotRequired[MatchPurposeType]

class IdMappingRuleBasedPropertiesTypeDef(TypedDict):
    ruleDefinitionType: IdMappingWorkflowRuleDefinitionTypeType
    attributeMatchingModel: AttributeMatchingModelType
    recordMatchingModel: RecordMatchingModelType
    rules: NotRequired[Sequence[RuleTypeDef]]

class RuleBasedPropertiesTypeDef(TypedDict):
    rules: Sequence[RuleTypeDef]
    attributeMatchingModel: AttributeMatchingModelType
    matchPurpose: NotRequired[MatchPurposeType]

RuleUnionTypeDef = Union[RuleTypeDef, RuleOutputTypeDef]

class ListIdMappingWorkflowsOutputTypeDef(TypedDict):
    workflowSummaries: list[IdMappingWorkflowSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

IdNamespaceSummaryTypeDef = TypedDict(
    "IdNamespaceSummaryTypeDef",
    {
        "idNamespaceName": str,
        "idNamespaceArn": str,
        "type": IdNamespaceTypeType,
        "createdAt": datetime,
        "updatedAt": datetime,
        "description": NotRequired[str],
        "idMappingWorkflowProperties": NotRequired[
            list[IdNamespaceIdMappingWorkflowMetadataTypeDef]
        ],
    },
)

class ProviderPropertiesOutputTypeDef(TypedDict):
    providerServiceArn: str
    providerConfiguration: NotRequired[dict[str, Any]]
    intermediateSourceConfiguration: NotRequired[IntermediateSourceConfigurationTypeDef]

class ProviderPropertiesTypeDef(TypedDict):
    providerServiceArn: str
    providerConfiguration: NotRequired[Mapping[str, Any]]
    intermediateSourceConfiguration: NotRequired[IntermediateSourceConfigurationTypeDef]

class ListIdMappingJobsOutputTypeDef(TypedDict):
    jobs: list[JobSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListMatchingJobsOutputTypeDef(TypedDict):
    jobs: list[JobSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListIdMappingJobsInputPaginateTypeDef(TypedDict):
    workflowName: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListIdMappingWorkflowsInputPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListIdNamespacesInputPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListMatchingJobsInputPaginateTypeDef(TypedDict):
    workflowName: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListMatchingWorkflowsInputPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListProviderServicesInputPaginateTypeDef(TypedDict):
    providerName: NotRequired[str]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListSchemaMappingsInputPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListMatchingWorkflowsOutputTypeDef(TypedDict):
    workflowSummaries: list[MatchingWorkflowSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListProviderServicesOutputTypeDef(TypedDict):
    providerServiceSummaries: list[ProviderServiceSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListSchemaMappingsOutputTypeDef(TypedDict):
    schemaList: list[SchemaMappingSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class MatchGroupTypeDef(TypedDict):
    records: list[MatchedRecordTypeDef]
    matchId: str
    matchRule: str

NamespaceProviderPropertiesUnionTypeDef = Union[
    NamespaceProviderPropertiesTypeDef, NamespaceProviderPropertiesOutputTypeDef
]

class OutputSourceOutputTypeDef(TypedDict):
    output: list[OutputAttributeTypeDef]
    KMSArn: NotRequired[str]
    outputS3Path: NotRequired[str]
    applyNormalization: NotRequired[bool]
    customerProfilesIntegrationConfig: NotRequired[CustomerProfilesIntegrationConfigTypeDef]

class OutputSourceTypeDef(TypedDict):
    output: Sequence[OutputAttributeTypeDef]
    KMSArn: NotRequired[str]
    outputS3Path: NotRequired[str]
    applyNormalization: NotRequired[bool]
    customerProfilesIntegrationConfig: NotRequired[CustomerProfilesIntegrationConfigTypeDef]

class ProviderComponentSchemaTypeDef(TypedDict):
    schemas: NotRequired[list[list[str]]]
    providerSchemaAttributes: NotRequired[list[ProviderSchemaAttributeTypeDef]]

class ProviderEndpointConfigurationTypeDef(TypedDict):
    marketplaceConfiguration: NotRequired[ProviderMarketplaceConfigurationTypeDef]

class RuleConditionPropertiesOutputTypeDef(TypedDict):
    rules: list[RuleConditionTypeDef]

class RuleConditionPropertiesTypeDef(TypedDict):
    rules: Sequence[RuleConditionTypeDef]

class IdNamespaceIdMappingWorkflowPropertiesOutputTypeDef(TypedDict):
    idMappingType: IdMappingTypeType
    ruleBasedProperties: NotRequired[NamespaceRuleBasedPropertiesOutputTypeDef]
    providerProperties: NotRequired[NamespaceProviderPropertiesOutputTypeDef]

class NamespaceRuleBasedPropertiesTypeDef(TypedDict):
    rules: NotRequired[Sequence[RuleUnionTypeDef]]
    ruleDefinitionTypes: NotRequired[Sequence[IdMappingWorkflowRuleDefinitionTypeType]]
    attributeMatchingModel: NotRequired[AttributeMatchingModelType]
    recordMatchingModels: NotRequired[Sequence[RecordMatchingModelType]]

class ListIdNamespacesOutputTypeDef(TypedDict):
    idNamespaceSummaries: list[IdNamespaceSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class IdMappingTechniquesOutputTypeDef(TypedDict):
    idMappingType: IdMappingTypeType
    ruleBasedProperties: NotRequired[IdMappingRuleBasedPropertiesOutputTypeDef]
    providerProperties: NotRequired[ProviderPropertiesOutputTypeDef]

class IdMappingTechniquesTypeDef(TypedDict):
    idMappingType: IdMappingTypeType
    ruleBasedProperties: NotRequired[IdMappingRuleBasedPropertiesTypeDef]
    providerProperties: NotRequired[ProviderPropertiesTypeDef]

class GenerateMatchIdOutputTypeDef(TypedDict):
    matchGroups: list[MatchGroupTypeDef]
    failedRecords: list[FailedRecordTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

OutputSourceUnionTypeDef = Union[OutputSourceTypeDef, OutputSourceOutputTypeDef]

class GetProviderServiceOutputTypeDef(TypedDict):
    providerName: str
    providerServiceName: str
    providerServiceDisplayName: str
    providerServiceType: ServiceTypeType
    providerServiceArn: str
    providerConfigurationDefinition: dict[str, Any]
    providerIdNameSpaceConfiguration: ProviderIdNameSpaceConfigurationTypeDef
    providerJobConfiguration: dict[str, Any]
    providerEndpointConfiguration: ProviderEndpointConfigurationTypeDef
    anonymizedOutput: bool
    providerEntityOutputDefinition: dict[str, Any]
    providerIntermediateDataAccessConfiguration: ProviderIntermediateDataAccessConfigurationTypeDef
    providerComponentSchema: ProviderComponentSchemaTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class ResolutionTechniquesOutputTypeDef(TypedDict):
    resolutionType: ResolutionTypeType
    ruleBasedProperties: NotRequired[RuleBasedPropertiesOutputTypeDef]
    ruleConditionProperties: NotRequired[RuleConditionPropertiesOutputTypeDef]
    providerProperties: NotRequired[ProviderPropertiesOutputTypeDef]

class ResolutionTechniquesTypeDef(TypedDict):
    resolutionType: ResolutionTypeType
    ruleBasedProperties: NotRequired[RuleBasedPropertiesTypeDef]
    ruleConditionProperties: NotRequired[RuleConditionPropertiesTypeDef]
    providerProperties: NotRequired[ProviderPropertiesTypeDef]

CreateIdNamespaceOutputTypeDef = TypedDict(
    "CreateIdNamespaceOutputTypeDef",
    {
        "idNamespaceName": str,
        "idNamespaceArn": str,
        "description": str,
        "inputSourceConfig": list[IdNamespaceInputSourceTypeDef],
        "idMappingWorkflowProperties": list[IdNamespaceIdMappingWorkflowPropertiesOutputTypeDef],
        "type": IdNamespaceTypeType,
        "roleArn": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "tags": dict[str, str],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
GetIdNamespaceOutputTypeDef = TypedDict(
    "GetIdNamespaceOutputTypeDef",
    {
        "idNamespaceName": str,
        "idNamespaceArn": str,
        "description": str,
        "inputSourceConfig": list[IdNamespaceInputSourceTypeDef],
        "idMappingWorkflowProperties": list[IdNamespaceIdMappingWorkflowPropertiesOutputTypeDef],
        "type": IdNamespaceTypeType,
        "roleArn": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "tags": dict[str, str],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
UpdateIdNamespaceOutputTypeDef = TypedDict(
    "UpdateIdNamespaceOutputTypeDef",
    {
        "idNamespaceName": str,
        "idNamespaceArn": str,
        "description": str,
        "inputSourceConfig": list[IdNamespaceInputSourceTypeDef],
        "idMappingWorkflowProperties": list[IdNamespaceIdMappingWorkflowPropertiesOutputTypeDef],
        "type": IdNamespaceTypeType,
        "roleArn": str,
        "createdAt": datetime,
        "updatedAt": datetime,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
NamespaceRuleBasedPropertiesUnionTypeDef = Union[
    NamespaceRuleBasedPropertiesTypeDef, NamespaceRuleBasedPropertiesOutputTypeDef
]

class CreateIdMappingWorkflowOutputTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    description: str
    inputSourceConfig: list[IdMappingWorkflowInputSourceTypeDef]
    outputSourceConfig: list[IdMappingWorkflowOutputSourceTypeDef]
    idMappingTechniques: IdMappingTechniquesOutputTypeDef
    incrementalRunConfig: IdMappingIncrementalRunConfigTypeDef
    roleArn: str
    ResponseMetadata: ResponseMetadataTypeDef

class GetIdMappingWorkflowOutputTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    description: str
    inputSourceConfig: list[IdMappingWorkflowInputSourceTypeDef]
    outputSourceConfig: list[IdMappingWorkflowOutputSourceTypeDef]
    idMappingTechniques: IdMappingTechniquesOutputTypeDef
    createdAt: datetime
    updatedAt: datetime
    incrementalRunConfig: IdMappingIncrementalRunConfigTypeDef
    roleArn: str
    tags: dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateIdMappingWorkflowOutputTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    description: str
    inputSourceConfig: list[IdMappingWorkflowInputSourceTypeDef]
    outputSourceConfig: list[IdMappingWorkflowOutputSourceTypeDef]
    idMappingTechniques: IdMappingTechniquesOutputTypeDef
    incrementalRunConfig: IdMappingIncrementalRunConfigTypeDef
    roleArn: str
    ResponseMetadata: ResponseMetadataTypeDef

IdMappingTechniquesUnionTypeDef = Union[
    IdMappingTechniquesTypeDef, IdMappingTechniquesOutputTypeDef
]

class CreateMatchingWorkflowOutputTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    description: str
    inputSourceConfig: list[InputSourceTypeDef]
    outputSourceConfig: list[OutputSourceOutputTypeDef]
    resolutionTechniques: ResolutionTechniquesOutputTypeDef
    incrementalRunConfig: IncrementalRunConfigTypeDef
    roleArn: str
    ResponseMetadata: ResponseMetadataTypeDef

class GetMatchingWorkflowOutputTypeDef(TypedDict):
    workflowName: str
    workflowArn: str
    description: str
    inputSourceConfig: list[InputSourceTypeDef]
    outputSourceConfig: list[OutputSourceOutputTypeDef]
    resolutionTechniques: ResolutionTechniquesOutputTypeDef
    createdAt: datetime
    updatedAt: datetime
    incrementalRunConfig: IncrementalRunConfigTypeDef
    roleArn: str
    tags: dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateMatchingWorkflowOutputTypeDef(TypedDict):
    workflowName: str
    description: str
    inputSourceConfig: list[InputSourceTypeDef]
    outputSourceConfig: list[OutputSourceOutputTypeDef]
    resolutionTechniques: ResolutionTechniquesOutputTypeDef
    incrementalRunConfig: IncrementalRunConfigTypeDef
    roleArn: str
    ResponseMetadata: ResponseMetadataTypeDef

ResolutionTechniquesUnionTypeDef = Union[
    ResolutionTechniquesTypeDef, ResolutionTechniquesOutputTypeDef
]

class IdNamespaceIdMappingWorkflowPropertiesTypeDef(TypedDict):
    idMappingType: IdMappingTypeType
    ruleBasedProperties: NotRequired[NamespaceRuleBasedPropertiesUnionTypeDef]
    providerProperties: NotRequired[NamespaceProviderPropertiesUnionTypeDef]

class CreateIdMappingWorkflowInputTypeDef(TypedDict):
    workflowName: str
    inputSourceConfig: Sequence[IdMappingWorkflowInputSourceTypeDef]
    idMappingTechniques: IdMappingTechniquesUnionTypeDef
    description: NotRequired[str]
    outputSourceConfig: NotRequired[Sequence[IdMappingWorkflowOutputSourceTypeDef]]
    incrementalRunConfig: NotRequired[IdMappingIncrementalRunConfigTypeDef]
    roleArn: NotRequired[str]
    tags: NotRequired[Mapping[str, str]]

class UpdateIdMappingWorkflowInputTypeDef(TypedDict):
    workflowName: str
    inputSourceConfig: Sequence[IdMappingWorkflowInputSourceTypeDef]
    idMappingTechniques: IdMappingTechniquesUnionTypeDef
    description: NotRequired[str]
    outputSourceConfig: NotRequired[Sequence[IdMappingWorkflowOutputSourceTypeDef]]
    incrementalRunConfig: NotRequired[IdMappingIncrementalRunConfigTypeDef]
    roleArn: NotRequired[str]

class CreateMatchingWorkflowInputTypeDef(TypedDict):
    workflowName: str
    inputSourceConfig: Sequence[InputSourceTypeDef]
    outputSourceConfig: Sequence[OutputSourceUnionTypeDef]
    resolutionTechniques: ResolutionTechniquesUnionTypeDef
    roleArn: str
    description: NotRequired[str]
    incrementalRunConfig: NotRequired[IncrementalRunConfigTypeDef]
    tags: NotRequired[Mapping[str, str]]

class UpdateMatchingWorkflowInputTypeDef(TypedDict):
    workflowName: str
    inputSourceConfig: Sequence[InputSourceTypeDef]
    outputSourceConfig: Sequence[OutputSourceUnionTypeDef]
    resolutionTechniques: ResolutionTechniquesUnionTypeDef
    roleArn: str
    description: NotRequired[str]
    incrementalRunConfig: NotRequired[IncrementalRunConfigTypeDef]

IdNamespaceIdMappingWorkflowPropertiesUnionTypeDef = Union[
    IdNamespaceIdMappingWorkflowPropertiesTypeDef,
    IdNamespaceIdMappingWorkflowPropertiesOutputTypeDef,
]
CreateIdNamespaceInputTypeDef = TypedDict(
    "CreateIdNamespaceInputTypeDef",
    {
        "idNamespaceName": str,
        "type": IdNamespaceTypeType,
        "description": NotRequired[str],
        "inputSourceConfig": NotRequired[Sequence[IdNamespaceInputSourceTypeDef]],
        "idMappingWorkflowProperties": NotRequired[
            Sequence[IdNamespaceIdMappingWorkflowPropertiesUnionTypeDef]
        ],
        "roleArn": NotRequired[str],
        "tags": NotRequired[Mapping[str, str]],
    },
)

class UpdateIdNamespaceInputTypeDef(TypedDict):
    idNamespaceName: str
    description: NotRequired[str]
    inputSourceConfig: NotRequired[Sequence[IdNamespaceInputSourceTypeDef]]
    idMappingWorkflowProperties: NotRequired[
        Sequence[IdNamespaceIdMappingWorkflowPropertiesUnionTypeDef]
    ]
    roleArn: NotRequired[str]



"""
Type annotations for entityresolution service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_entityresolution.client import EntityResolutionClient

    session = Session()
    client: EntityResolutionClient = session.client("entityresolution")
    ```
"""

from __future__ import annotations

import sys
from collections.abc import Mapping
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    ListIdMappingJobsPaginator,
    ListIdMappingWorkflowsPaginator,
    ListIdNamespacesPaginator,
    ListMatchingJobsPaginator,
    ListMatchingWorkflowsPaginator,
    ListProviderServicesPaginator,
    ListSchemaMappingsPaginator,
)
from .type_defs import (
    AddPolicyStatementInputTypeDef,
    AddPolicyStatementOutputTypeDef,
    BatchDeleteUniqueIdInputTypeDef,
    BatchDeleteUniqueIdOutputTypeDef,
    CreateIdMappingWorkflowInputTypeDef,
    CreateIdMappingWorkflowOutputTypeDef,
    CreateIdNamespaceInputTypeDef,
    CreateIdNamespaceOutputTypeDef,
    CreateMatchingWorkflowInputTypeDef,
    CreateMatchingWorkflowOutputTypeDef,
    CreateSchemaMappingInputTypeDef,
    CreateSchemaMappingOutputTypeDef,
    DeleteIdMappingWorkflowInputTypeDef,
    DeleteIdMappingWorkflowOutputTypeDef,
    DeleteIdNamespaceInputTypeDef,
    DeleteIdNamespaceOutputTypeDef,
    DeleteMatchingWorkflowInputTypeDef,
    DeleteMatchingWorkflowOutputTypeDef,
    DeletePolicyStatementInputTypeDef,
    DeletePolicyStatementOutputTypeDef,
    DeleteSchemaMappingInputTypeDef,
    DeleteSchemaMappingOutputTypeDef,
    GenerateMatchIdInputTypeDef,
    GenerateMatchIdOutputTypeDef,
    GetIdMappingJobInputTypeDef,
    GetIdMappingJobOutputTypeDef,
    GetIdMappingWorkflowInputTypeDef,
    GetIdMappingWorkflowOutputTypeDef,
    GetIdNamespaceInputTypeDef,
    GetIdNamespaceOutputTypeDef,
    GetMatchIdInputTypeDef,
    GetMatchIdOutputTypeDef,
    GetMatchingJobInputTypeDef,
    GetMatchingJobOutputTypeDef,
    GetMatchingWorkflowInputTypeDef,
    GetMatchingWorkflowOutputTypeDef,
    GetPolicyInputTypeDef,
    GetPolicyOutputTypeDef,
    GetProviderServiceInputTypeDef,
    GetProviderServiceOutputTypeDef,
    GetSchemaMappingInputTypeDef,
    GetSchemaMappingOutputTypeDef,
    ListIdMappingJobsInputTypeDef,
    ListIdMappingJobsOutputTypeDef,
    ListIdMappingWorkflowsInputTypeDef,
    ListIdMappingWorkflowsOutputTypeDef,
    ListIdNamespacesInputTypeDef,
    ListIdNamespacesOutputTypeDef,
    ListMatchingJobsInputTypeDef,
    ListMatchingJobsOutputTypeDef,
    ListMatchingWorkflowsInputTypeDef,
    ListMatchingWorkflowsOutputTypeDef,
    ListProviderServicesInputTypeDef,
    ListProviderServicesOutputTypeDef,
    ListSchemaMappingsInputTypeDef,
    ListSchemaMappingsOutputTypeDef,
    ListTagsForResourceInputTypeDef,
    ListTagsForResourceOutputTypeDef,
    PutPolicyInputTypeDef,
    PutPolicyOutputTypeDef,
    StartIdMappingJobInputTypeDef,
    StartIdMappingJobOutputTypeDef,
    StartMatchingJobInputTypeDef,
    StartMatchingJobOutputTypeDef,
    TagResourceInputTypeDef,
    UntagResourceInputTypeDef,
    UpdateIdMappingWorkflowInputTypeDef,
    UpdateIdMappingWorkflowOutputTypeDef,
    UpdateIdNamespaceInputTypeDef,
    UpdateIdNamespaceOutputTypeDef,
    UpdateMatchingWorkflowInputTypeDef,
    UpdateMatchingWorkflowOutputTypeDef,
    UpdateSchemaMappingInputTypeDef,
    UpdateSchemaMappingOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("EntityResolutionClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: type[BotocoreClientError]
    ClientError: type[BotocoreClientError]
    ConflictException: type[BotocoreClientError]
    ExceedsLimitException: type[BotocoreClientError]
    InternalServerException: type[BotocoreClientError]
    ResourceNotFoundException: type[BotocoreClientError]
    ThrottlingException: type[BotocoreClientError]
    ValidationException: type[BotocoreClientError]


class EntityResolutionClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution.html#EntityResolution.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        EntityResolutionClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution.html#EntityResolution.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#generate_presigned_url)
        """

    def add_policy_statement(
        self, **kwargs: Unpack[AddPolicyStatementInputTypeDef]
    ) -> AddPolicyStatementOutputTypeDef:
        """
        Adds a policy statement object.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/add_policy_statement.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#add_policy_statement)
        """

    def batch_delete_unique_id(
        self, **kwargs: Unpack[BatchDeleteUniqueIdInputTypeDef]
    ) -> BatchDeleteUniqueIdOutputTypeDef:
        """
        Deletes multiple unique IDs in a matching workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/batch_delete_unique_id.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#batch_delete_unique_id)
        """

    def create_id_mapping_workflow(
        self, **kwargs: Unpack[CreateIdMappingWorkflowInputTypeDef]
    ) -> CreateIdMappingWorkflowOutputTypeDef:
        """
        Creates an <code>IdMappingWorkflow</code> object which stores the configuration
        of the data processing job to be run.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/create_id_mapping_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#create_id_mapping_workflow)
        """

    def create_id_namespace(
        self, **kwargs: Unpack[CreateIdNamespaceInputTypeDef]
    ) -> CreateIdNamespaceOutputTypeDef:
        """
        Creates an ID namespace object which will help customers provide metadata
        explaining their dataset and how to use it.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/create_id_namespace.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#create_id_namespace)
        """

    def create_matching_workflow(
        self, **kwargs: Unpack[CreateMatchingWorkflowInputTypeDef]
    ) -> CreateMatchingWorkflowOutputTypeDef:
        """
        Creates a matching workflow that defines the configuration for a data
        processing job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/create_matching_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#create_matching_workflow)
        """

    def create_schema_mapping(
        self, **kwargs: Unpack[CreateSchemaMappingInputTypeDef]
    ) -> CreateSchemaMappingOutputTypeDef:
        """
        Creates a schema mapping, which defines the schema of the input customer
        records table.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/create_schema_mapping.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#create_schema_mapping)
        """

    def delete_id_mapping_workflow(
        self, **kwargs: Unpack[DeleteIdMappingWorkflowInputTypeDef]
    ) -> DeleteIdMappingWorkflowOutputTypeDef:
        """
        Deletes the <code>IdMappingWorkflow</code> with a given name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/delete_id_mapping_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#delete_id_mapping_workflow)
        """

    def delete_id_namespace(
        self, **kwargs: Unpack[DeleteIdNamespaceInputTypeDef]
    ) -> DeleteIdNamespaceOutputTypeDef:
        """
        Deletes the <code>IdNamespace</code> with a given name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/delete_id_namespace.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#delete_id_namespace)
        """

    def delete_matching_workflow(
        self, **kwargs: Unpack[DeleteMatchingWorkflowInputTypeDef]
    ) -> DeleteMatchingWorkflowOutputTypeDef:
        """
        Deletes the <code>MatchingWorkflow</code> with a given name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/delete_matching_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#delete_matching_workflow)
        """

    def delete_policy_statement(
        self, **kwargs: Unpack[DeletePolicyStatementInputTypeDef]
    ) -> DeletePolicyStatementOutputTypeDef:
        """
        Deletes the policy statement.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/delete_policy_statement.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#delete_policy_statement)
        """

    def delete_schema_mapping(
        self, **kwargs: Unpack[DeleteSchemaMappingInputTypeDef]
    ) -> DeleteSchemaMappingOutputTypeDef:
        """
        Deletes the <code>SchemaMapping</code> with a given name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/delete_schema_mapping.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#delete_schema_mapping)
        """

    def generate_match_id(
        self, **kwargs: Unpack[GenerateMatchIdInputTypeDef]
    ) -> GenerateMatchIdOutputTypeDef:
        """
        Generates or retrieves Match IDs for records using a rule-based matching
        workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/generate_match_id.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#generate_match_id)
        """

    def get_id_mapping_job(
        self, **kwargs: Unpack[GetIdMappingJobInputTypeDef]
    ) -> GetIdMappingJobOutputTypeDef:
        """
        Returns the status, metrics, and errors (if there are any) that are associated
        with a job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_id_mapping_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_id_mapping_job)
        """

    def get_id_mapping_workflow(
        self, **kwargs: Unpack[GetIdMappingWorkflowInputTypeDef]
    ) -> GetIdMappingWorkflowOutputTypeDef:
        """
        Returns the <code>IdMappingWorkflow</code> with a given name, if it exists.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_id_mapping_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_id_mapping_workflow)
        """

    def get_id_namespace(
        self, **kwargs: Unpack[GetIdNamespaceInputTypeDef]
    ) -> GetIdNamespaceOutputTypeDef:
        """
        Returns the <code>IdNamespace</code> with a given name, if it exists.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_id_namespace.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_id_namespace)
        """

    def get_match_id(self, **kwargs: Unpack[GetMatchIdInputTypeDef]) -> GetMatchIdOutputTypeDef:
        """
        Returns the corresponding Match ID of a customer record if the record has been
        processed in a rule-based matching workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_match_id.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_match_id)
        """

    def get_matching_job(
        self, **kwargs: Unpack[GetMatchingJobInputTypeDef]
    ) -> GetMatchingJobOutputTypeDef:
        """
        Returns the status, metrics, and errors (if there are any) that are associated
        with a job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_matching_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_matching_job)
        """

    def get_matching_workflow(
        self, **kwargs: Unpack[GetMatchingWorkflowInputTypeDef]
    ) -> GetMatchingWorkflowOutputTypeDef:
        """
        Returns the <code>MatchingWorkflow</code> with a given name, if it exists.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_matching_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_matching_workflow)
        """

    def get_policy(self, **kwargs: Unpack[GetPolicyInputTypeDef]) -> GetPolicyOutputTypeDef:
        """
        Returns the resource-based policy.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_policy)
        """

    def get_provider_service(
        self, **kwargs: Unpack[GetProviderServiceInputTypeDef]
    ) -> GetProviderServiceOutputTypeDef:
        """
        Returns the <code>ProviderService</code> of a given name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_provider_service.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_provider_service)
        """

    def get_schema_mapping(
        self, **kwargs: Unpack[GetSchemaMappingInputTypeDef]
    ) -> GetSchemaMappingOutputTypeDef:
        """
        Returns the SchemaMapping of a given name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_schema_mapping.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_schema_mapping)
        """

    def list_id_mapping_jobs(
        self, **kwargs: Unpack[ListIdMappingJobsInputTypeDef]
    ) -> ListIdMappingJobsOutputTypeDef:
        """
        Lists all ID mapping jobs for a given workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_id_mapping_jobs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_id_mapping_jobs)
        """

    def list_id_mapping_workflows(
        self, **kwargs: Unpack[ListIdMappingWorkflowsInputTypeDef]
    ) -> ListIdMappingWorkflowsOutputTypeDef:
        """
        Returns a list of all the <code>IdMappingWorkflows</code> that have been
        created for an Amazon Web Services account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_id_mapping_workflows.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_id_mapping_workflows)
        """

    def list_id_namespaces(
        self, **kwargs: Unpack[ListIdNamespacesInputTypeDef]
    ) -> ListIdNamespacesOutputTypeDef:
        """
        Returns a list of all ID namespaces.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_id_namespaces.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_id_namespaces)
        """

    def list_matching_jobs(
        self, **kwargs: Unpack[ListMatchingJobsInputTypeDef]
    ) -> ListMatchingJobsOutputTypeDef:
        """
        Lists all jobs for a given workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_matching_jobs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_matching_jobs)
        """

    def list_matching_workflows(
        self, **kwargs: Unpack[ListMatchingWorkflowsInputTypeDef]
    ) -> ListMatchingWorkflowsOutputTypeDef:
        """
        Returns a list of all the <code>MatchingWorkflows</code> that have been created
        for an Amazon Web Services account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_matching_workflows.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_matching_workflows)
        """

    def list_provider_services(
        self, **kwargs: Unpack[ListProviderServicesInputTypeDef]
    ) -> ListProviderServicesOutputTypeDef:
        """
        Returns a list of all the <code>ProviderServices</code> that are available in
        this Amazon Web Services Region.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_provider_services.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_provider_services)
        """

    def list_schema_mappings(
        self, **kwargs: Unpack[ListSchemaMappingsInputTypeDef]
    ) -> ListSchemaMappingsOutputTypeDef:
        """
        Returns a list of all the <code>SchemaMappings</code> that have been created
        for an Amazon Web Services account.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_schema_mappings.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_schema_mappings)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceInputTypeDef]
    ) -> ListTagsForResourceOutputTypeDef:
        """
        Displays the tags associated with an Entity Resolution resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#list_tags_for_resource)
        """

    def put_policy(self, **kwargs: Unpack[PutPolicyInputTypeDef]) -> PutPolicyOutputTypeDef:
        """
        Updates the resource-based policy.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/put_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#put_policy)
        """

    def start_id_mapping_job(
        self, **kwargs: Unpack[StartIdMappingJobInputTypeDef]
    ) -> StartIdMappingJobOutputTypeDef:
        """
        Starts the <code>IdMappingJob</code> of a workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/start_id_mapping_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#start_id_mapping_job)
        """

    def start_matching_job(
        self, **kwargs: Unpack[StartMatchingJobInputTypeDef]
    ) -> StartMatchingJobOutputTypeDef:
        """
        Starts the <code>MatchingJob</code> of a workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/start_matching_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#start_matching_job)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceInputTypeDef]) -> dict[str, Any]:
        """
        Assigns one or more tags (key-value pairs) to the specified Entity Resolution
        resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceInputTypeDef]) -> dict[str, Any]:
        """
        Removes one or more tags from the specified Entity Resolution resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#untag_resource)
        """

    def update_id_mapping_workflow(
        self, **kwargs: Unpack[UpdateIdMappingWorkflowInputTypeDef]
    ) -> UpdateIdMappingWorkflowOutputTypeDef:
        """
        Updates an existing <code>IdMappingWorkflow</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/update_id_mapping_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#update_id_mapping_workflow)
        """

    def update_id_namespace(
        self, **kwargs: Unpack[UpdateIdNamespaceInputTypeDef]
    ) -> UpdateIdNamespaceOutputTypeDef:
        """
        Updates an existing ID namespace.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/update_id_namespace.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#update_id_namespace)
        """

    def update_matching_workflow(
        self, **kwargs: Unpack[UpdateMatchingWorkflowInputTypeDef]
    ) -> UpdateMatchingWorkflowOutputTypeDef:
        """
        Updates an existing matching workflow.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/update_matching_workflow.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#update_matching_workflow)
        """

    def update_schema_mapping(
        self, **kwargs: Unpack[UpdateSchemaMappingInputTypeDef]
    ) -> UpdateSchemaMappingOutputTypeDef:
        """
        Updates a schema mapping.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/update_schema_mapping.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#update_schema_mapping)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_id_mapping_jobs"]
    ) -> ListIdMappingJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_id_mapping_workflows"]
    ) -> ListIdMappingWorkflowsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_id_namespaces"]
    ) -> ListIdNamespacesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_matching_jobs"]
    ) -> ListMatchingJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_matching_workflows"]
    ) -> ListMatchingWorkflowsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_provider_services"]
    ) -> ListProviderServicesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_schema_mappings"]
    ) -> ListSchemaMappingsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/client/#get_paginator)
        """



"""
Type annotations for entityresolution service client paginators.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from types_boto3_entityresolution.client import EntityResolutionClient
    from types_boto3_entityresolution.paginator import (
        ListIdMappingJobsPaginator,
        ListIdMappingWorkflowsPaginator,
        ListIdNamespacesPaginator,
        ListMatchingJobsPaginator,
        ListMatchingWorkflowsPaginator,
        ListProviderServicesPaginator,
        ListSchemaMappingsPaginator,
    )

    session = Session()
    client: EntityResolutionClient = session.client("entityresolution")

    list_id_mapping_jobs_paginator: ListIdMappingJobsPaginator = client.get_paginator("list_id_mapping_jobs")
    list_id_mapping_workflows_paginator: ListIdMappingWorkflowsPaginator = client.get_paginator("list_id_mapping_workflows")
    list_id_namespaces_paginator: ListIdNamespacesPaginator = client.get_paginator("list_id_namespaces")
    list_matching_jobs_paginator: ListMatchingJobsPaginator = client.get_paginator("list_matching_jobs")
    list_matching_workflows_paginator: ListMatchingWorkflowsPaginator = client.get_paginator("list_matching_workflows")
    list_provider_services_paginator: ListProviderServicesPaginator = client.get_paginator("list_provider_services")
    list_schema_mappings_paginator: ListSchemaMappingsPaginator = client.get_paginator("list_schema_mappings")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListIdMappingJobsInputPaginateTypeDef,
    ListIdMappingJobsOutputTypeDef,
    ListIdMappingWorkflowsInputPaginateTypeDef,
    ListIdMappingWorkflowsOutputTypeDef,
    ListIdNamespacesInputPaginateTypeDef,
    ListIdNamespacesOutputTypeDef,
    ListMatchingJobsInputPaginateTypeDef,
    ListMatchingJobsOutputTypeDef,
    ListMatchingWorkflowsInputPaginateTypeDef,
    ListMatchingWorkflowsOutputTypeDef,
    ListProviderServicesInputPaginateTypeDef,
    ListProviderServicesOutputTypeDef,
    ListSchemaMappingsInputPaginateTypeDef,
    ListSchemaMappingsOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListIdMappingJobsPaginator",
    "ListIdMappingWorkflowsPaginator",
    "ListIdNamespacesPaginator",
    "ListMatchingJobsPaginator",
    "ListMatchingWorkflowsPaginator",
    "ListProviderServicesPaginator",
    "ListSchemaMappingsPaginator",
)


if TYPE_CHECKING:
    _ListIdMappingJobsPaginatorBase = Paginator[ListIdMappingJobsOutputTypeDef]
else:
    _ListIdMappingJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListIdMappingJobsPaginator(_ListIdMappingJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListIdMappingJobs.html#EntityResolution.Paginator.ListIdMappingJobs)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listidmappingjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListIdMappingJobsInputPaginateTypeDef]
    ) -> PageIterator[ListIdMappingJobsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListIdMappingJobs.html#EntityResolution.Paginator.ListIdMappingJobs.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listidmappingjobspaginator)
        """


if TYPE_CHECKING:
    _ListIdMappingWorkflowsPaginatorBase = Paginator[ListIdMappingWorkflowsOutputTypeDef]
else:
    _ListIdMappingWorkflowsPaginatorBase = Paginator  # type: ignore[assignment]


class ListIdMappingWorkflowsPaginator(_ListIdMappingWorkflowsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListIdMappingWorkflows.html#EntityResolution.Paginator.ListIdMappingWorkflows)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listidmappingworkflowspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListIdMappingWorkflowsInputPaginateTypeDef]
    ) -> PageIterator[ListIdMappingWorkflowsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListIdMappingWorkflows.html#EntityResolution.Paginator.ListIdMappingWorkflows.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listidmappingworkflowspaginator)
        """


if TYPE_CHECKING:
    _ListIdNamespacesPaginatorBase = Paginator[ListIdNamespacesOutputTypeDef]
else:
    _ListIdNamespacesPaginatorBase = Paginator  # type: ignore[assignment]


class ListIdNamespacesPaginator(_ListIdNamespacesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListIdNamespaces.html#EntityResolution.Paginator.ListIdNamespaces)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listidnamespacespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListIdNamespacesInputPaginateTypeDef]
    ) -> PageIterator[ListIdNamespacesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListIdNamespaces.html#EntityResolution.Paginator.ListIdNamespaces.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listidnamespacespaginator)
        """


if TYPE_CHECKING:
    _ListMatchingJobsPaginatorBase = Paginator[ListMatchingJobsOutputTypeDef]
else:
    _ListMatchingJobsPaginatorBase = Paginator  # type: ignore[assignment]


class ListMatchingJobsPaginator(_ListMatchingJobsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListMatchingJobs.html#EntityResolution.Paginator.ListMatchingJobs)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listmatchingjobspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListMatchingJobsInputPaginateTypeDef]
    ) -> PageIterator[ListMatchingJobsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListMatchingJobs.html#EntityResolution.Paginator.ListMatchingJobs.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listmatchingjobspaginator)
        """


if TYPE_CHECKING:
    _ListMatchingWorkflowsPaginatorBase = Paginator[ListMatchingWorkflowsOutputTypeDef]
else:
    _ListMatchingWorkflowsPaginatorBase = Paginator  # type: ignore[assignment]


class ListMatchingWorkflowsPaginator(_ListMatchingWorkflowsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListMatchingWorkflows.html#EntityResolution.Paginator.ListMatchingWorkflows)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listmatchingworkflowspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListMatchingWorkflowsInputPaginateTypeDef]
    ) -> PageIterator[ListMatchingWorkflowsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListMatchingWorkflows.html#EntityResolution.Paginator.ListMatchingWorkflows.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listmatchingworkflowspaginator)
        """


if TYPE_CHECKING:
    _ListProviderServicesPaginatorBase = Paginator[ListProviderServicesOutputTypeDef]
else:
    _ListProviderServicesPaginatorBase = Paginator  # type: ignore[assignment]


class ListProviderServicesPaginator(_ListProviderServicesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListProviderServices.html#EntityResolution.Paginator.ListProviderServices)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listproviderservicespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListProviderServicesInputPaginateTypeDef]
    ) -> PageIterator[ListProviderServicesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListProviderServices.html#EntityResolution.Paginator.ListProviderServices.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listproviderservicespaginator)
        """


if TYPE_CHECKING:
    _ListSchemaMappingsPaginatorBase = Paginator[ListSchemaMappingsOutputTypeDef]
else:
    _ListSchemaMappingsPaginatorBase = Paginator  # type: ignore[assignment]


class ListSchemaMappingsPaginator(_ListSchemaMappingsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListSchemaMappings.html#EntityResolution.Paginator.ListSchemaMappings)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listschemamappingspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListSchemaMappingsInputPaginateTypeDef]
    ) -> PageIterator[ListSchemaMappingsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/entityresolution/paginator/ListSchemaMappings.html#EntityResolution.Paginator.ListSchemaMappings.paginate)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_entityresolution/paginators/#listschemamappingspaginator)
        """
